@@ -183,7 +183,6 @@ fi
 
 if [[ $CLOUDPLATFORM == "AZURE" ]];then
   #Parameters for Cloud deployment spcific
-  DEV_MODE=$(get_parameter_value dev_mode)
   #PG_DISK_SIZE=$(get_parameter_value pg_disk_size)
   SC_SKU=$(get_parameter_value storageclass_sku)
 
@@ -217,6 +216,9 @@ if [[ $CLOUDPLATFORM == "AZURE" ]];then
   # Database disk size, common for both aks and gke
   PG_DISK_SIZE=$(get_parameter_value pg_disk_size)
 
+  #Pod CIDR
+  POD_CIDR=$(get_parameter_value kubernetes_pod_cidr)
+
 fi
 
 
