@@ -29,7 +29,7 @@ SCALETIMEOUT = 50
 HELM_UPGRADE_TIMEOUT = "300s"
 
 #timeout setting for helm rollback command
-HELM_ROLLBACK_TIMEOUT = "900s"
+HELM_ROLLBACK_TIMEOUT = "1800s"
 
 #components in stages less or equal than this value will enforce re-deploy each time running deploy
 ENFORCE_REDEPLOY_STAGES = 0
@@ -1061,7 +1061,7 @@ def rollback_charts(deploy_list, namespace, interval, snapshot_name):
           # when target_revision not exist, means this release did not exist in last version, we will delete this release as rollback
           else:
             logger.info("Running helm cmd to delete [" + release + "] as rollback\n > helm delete -n " + namespace + " " + release)
-            cmd_proc = exec_cmd_parallel("helm delete -n " + namespace + " " + release)
+            cmd_proc = exec_cmd_parallel("helm delete -n " + namespace + " " + release + " --timeout " + HELM_ROLLBACK_TIMEOUT)
             if cmd_proc != None:
               process_dict[release] = cmd_proc
         else:
