@@ -453,6 +453,9 @@ EOM
 			EOF
       fi
 
+      ## Generate es java keystore/truststore and insert into elastic-tls
+      gen_java_cert $CMS_NAMESPACE
+
       ## Check if to update elastic users
       if kubectl get pod cms-es-logging-master-0 cms-es-application-master-0 -n $CMS_NAMESPACE &>/dev/null; then
         if [[ -n "$ELASTICSTACK_MANAGE_PASSWORD" || -n "$ELASTICSTACK_MONITOR_PASSWORD" ]];then
@@ -795,6 +798,13 @@ EOM
       else
         LB_WHITE_LIST_sed=$EXT_WHITE_LIST_sed
       fi
+
+      ## add pod cidr to lbWhitelist
+      if [[ -n "$POD_CIDR" ]] && [[ ${CLOUDPLATFORM} == "AZURE" ]]; then
+        LB_WHITE_LIST_sed_podcidr=$(echo "[$POD_CIDR]"|sed -e 's/\//\\\//g'|sed -e 's/]/,/g')$(echo $LB_WHITE_LIST_sed|sed -e 's/\[//g')
+        LB_WHITE_LIST_sed=$LB_WHITE_LIST_sed_podcidr
+      fi
+
       echo "[INFO] Updating cms_haproxy lbWhiteList ${LB_WHITE_LIST_sed}"
       sed -i '/^cms_haproxy:/{:a;N;/  lbWhiteList:.*/!{$!ba};s/  lbWhiteList:.*/  lbWhiteList: '$LB_WHITE_LIST_sed'/}' ${PRODUCTSVAR_FILE}
 
